@@ -709,7 +709,7 @@ def generate_atom_feeds(app):
         feed.title(feed_title)
         feed.link(href=url)
         feed.subtitle(blog.blog_feed_subtitle)
-        feed.link(href=feed_url)
+        feed.link(href=feed_url, rel="self")
         feed.language(app.config.language)
         feed.generator("ABlog", ablog.__version__, "https://ablog.readthedocs.org/")
 
@@ -741,17 +741,18 @@ def generate_atom_feeds(app):
 
             # Entry values that support templates
             title = post.title
-            if post.excerpt:
-                summary = " ".join(paragraph.astext() for paragraph in post.excerpt[0])
-            else:
-                summary = ""
+            summary = "".join(paragraph.astext() for paragraph in post.excerpt)
             template_values = {}
             for element in ("title", "summary", "content"):
                 if element in feed_templates:
                     template_values[element] = jinja2.Template(feed_templates[element]).render(**locals())
             feed_entry.title(template_values.get("title", title))
-            feed_entry.summary(template_values.get("summary", summary))
-            feed_entry.content(content=template_values.get("content", content), type="html")
+            summary = template_values.get("summary", summary)
+            if summary:
+                feed_entry.summary(summary)
+            content = template_values.get("content", content)
+            if content:
+                feed_entry.content(content=content, type="html")
 
         parent_dir = os.path.dirname(feed_path)
         if not os.path.isdir(parent_dir):
